==> shardingsphere-infra-util-5.2.1-sources.jar: org/apache/shardingsphere/infra/util/exception/internal/ShardingSphereInternalException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.util.exception.internal;

import lombok.NoArgsConstructor;

/**
 * ShardingSphere internal exception.
 */
@NoArgsConstructor
public abstract class ShardingSphereInternalException extends Exception {
    
    private static final long serialVersionUID = -8238061892944243621L;
    
    public ShardingSphereInternalException(final String errorMessage, final Object... args) {
        super(String.format(errorMessage, args));
    }
    
    public ShardingSphereInternalException(final Exception cause) {
        super(cause);
    }
    
    public ShardingSphereInternalException(final String message, final Exception cause) {
        super(message, cause);
    }
}

==> shardingsphere-infra-util-5.4.0-sources.jar: org/apache/shardingsphere/infra/util/exception/internal/ShardingSphereInternalException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.util.exception.internal;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;

/**
 * ShardingSphere internal exception.
 */
@NoArgsConstructor(access = AccessLevel.PROTECTED)
public abstract class ShardingSphereInternalException extends Exception {
    
    private static final long serialVersionUID = -8238061892944243621L;
    
    protected ShardingSphereInternalException(final String errorMessage, final Object... args) {
        super(String.format(errorMessage, args));
    }
    
    protected ShardingSphereInternalException(final Exception cause) {
        super(cause);
    }
    
    protected ShardingSphereInternalException(final String message, final Exception cause) {
        super(message, cause);
    }
}
